==> assert-has-iterator-symbol-support-0.0.8.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# Iterator Symbol Support

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Detect native [`Symbol.iterator`][mdn-iterator-symbol] support.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-has-iterator-symbol-support
```

</section>

<section class="usage">

## Usage

```javascript
var hasIteratorSymbolSupport = require( '@stdlib/assert-has-iterator-symbol-support' );
```

#### hasIteratorSymbolSupport()

Detects if a runtime environment supports ES2015 [`Symbol.iterator`][mdn-iterator-symbol].

```javascript
var bool = hasIteratorSymbolSupport();
// returns <boolean>
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var hasIteratorSymbolSupport = require( '@stdlib/assert-has-iterator-symbol-support' );

var bool = hasIteratorSymbolSupport();
if ( bool ) {
    console.log( 'Environment has Symbol.iterator support.' );
} else {
    console.log( 'Environment lacks Symbol.iterator support.' );
}
```

</section>

<!-- /.examples -->

* * *

<section class="cli">

## CLI

<section class="installation">

## Installation

To use the module as a general utility, install the module globally

```bash
npm install -g @stdlib/assert-has-iterator-symbol-support
```

</section>

<!-- CLI usage documentation. -->

<section class="usage">

### Usage

```text
Usage: has-iterator-symbol-support [options]

Options:

  -h,    --help                Print this message.
  -V,    --version             Print the package version.
```

</section>

<!-- /.usage -->

<section class="examples">

### Examples

```bash
$ has-iterator-symbol-support
<boolean>
```

</section>

<!-- /.examples -->

</section>

<!-- /.cli -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/assert/has-async-iterator-symbol-support`][@stdlib/assert/has-async-iterator-symbol-support]</span><span class="delimiter">: </span><span class="description">detect native Symbol.asyncIterator support.</span>
-   <span class="package-name">[`@stdlib/assert/has-symbol-support`][@stdlib/assert/has-symbol-support]</span><span class="delimiter">: </span><span class="description">detect native Symbol support.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-has-iterator-symbol-support.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-has-iterator-symbol-support

[test-image]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-has-iterator-symbol-support/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-has-iterator-symbol-support?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-has-iterator-symbol-support.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-has-iterator-symbol-support/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-has-iterator-symbol-support/main/LICENSE

[mdn-iterator-symbol]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol/iterator

<!-- <related-links> -->

[@stdlib/assert/has-async-iterator-symbol-support]: https://www.npmjs.com/package/@stdlib/assert-has-async-iterator-symbol-support

[@stdlib/assert/has-symbol-support]: https://www.npmjs.com/package/@stdlib/assert-has-symbol-support

<!-- </related-links> -->

</section>

<!-- /.links -->

==> assert-has-iterator-symbol-support-0.1.0.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# Iterator Symbol Support

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Detect native [`Symbol.iterator`][mdn-iterator-symbol] support.

<section class="installation">

## Installation

```bash
npm install @stdlib/assert-has-iterator-symbol-support
```

</section>

<section class="usage">

## Usage

```javascript
var hasIteratorSymbolSupport = require( '@stdlib/assert-has-iterator-symbol-support' );
```

#### hasIteratorSymbolSupport()

Detects if a runtime environment supports ES2015 [`Symbol.iterator`][mdn-iterator-symbol].

```javascript
var bool = hasIteratorSymbolSupport();
// returns <boolean>
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var hasIteratorSymbolSupport = require( '@stdlib/assert-has-iterator-symbol-support' );

var bool = hasIteratorSymbolSupport();
if ( bool ) {
    console.log( 'Environment has Symbol.iterator support.' );
} else {
    console.log( 'Environment lacks Symbol.iterator support.' );
}
```

</section>

<!-- /.examples -->



<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

## See Also

-   <span class="package-name">[`@stdlib/assert-has-iterator-symbol-support-cli`][@stdlib/assert-has-iterator-symbol-support-cli]</span><span class="delimiter">: </span><span class="description">CLI package for use as a command-line utility.</span>
-   <span class="package-name">[`@stdlib/assert-has-async-iterator-symbol-support`][@stdlib/assert/has-async-iterator-symbol-support]</span><span class="delimiter">: </span><span class="description">detect native Symbol.asyncIterator support.</span>
-   <span class="package-name">[`@stdlib/assert-has-symbol-support`][@stdlib/assert/has-symbol-support]</span><span class="delimiter">: </span><span class="description">detect native Symbol support.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2023. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[@stdlib/assert-has-iterator-symbol-support-cli]: https://www.npmjs.com/package/@stdlib/assert-has-iterator-symbol-support-cli

[npm-image]: http://img.shields.io/npm/v/@stdlib/assert-has-iterator-symbol-support.svg
[npm-url]: https://npmjs.org/package/@stdlib/assert-has-iterator-symbol-support

[test-image]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/actions/workflows/test.yml/badge.svg?branch=v0.1.0
[test-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/actions/workflows/test.yml?query=branch:v0.1.0

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/assert-has-iterator-symbol-support/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/assert-has-iterator-symbol-support?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/assert-has-iterator-symbol-support.svg
[dependencies-url]: https://david-dm.org/stdlib-js/assert-has-iterator-symbol-support/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[cli-section]: https://github.com/stdlib-js/assert-has-iterator-symbol-support#cli
[cli-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/cli
[@stdlib/assert-has-iterator-symbol-support]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/main

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/deno
[umd-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/umd
[esm-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/tree/esm
[branches-url]: https://github.com/stdlib-js/assert-has-iterator-symbol-support/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/assert-has-iterator-symbol-support/main/LICENSE

[mdn-iterator-symbol]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol/iterator

<!-- <related-links> -->

[@stdlib/assert/has-async-iterator-symbol-support]: https://www.npmjs.com/package/@stdlib/assert-has-async-iterator-symbol-support

[@stdlib/assert/has-symbol-support]: https://www.npmjs.com/package/@stdlib/assert-has-symbol-support

<!-- </related-links> -->

</section>

<!-- /.links -->
